==> shoplazza-cli-0.1.8.tgz: package/lib/checkout/push.js <==
const fs = require('fs');
const inquirer = require('inquirer');
const api = require('./api');
const loading = require('loading-cli');
const {
  getExtensionInfo,
  getExtensionConfig,
  getDistPath,
  useSelectExtensionMode,
  setExtensionConfig,
  checkLocalExtension,
  getProjectConfig
} = require('./util');
const fsExtra = require('fs-extra');
const { consoleBlue, consoleSuccess, consoleError, consoleWarn } = require('./console');
const { viteBuild } = require('./build');
const { verifyConfig } = require('./verify');

module.exports = async () => {
  try {
    await verifyConfig();
    const extensionInfo = await initSelectedExtensionInfo();
    consoleBlue('Starting to build:');
    const composeCommands = {
      id: extensionInfo.name
    }; // 兼容旧代码处理
    await viteBuild(composeCommands);
    consoleBlue('Starting to upload:');
    await uploadOSS(composeCommands);
    consoleBlue('Starting to push:');
    await pushExtension(composeCommands);
  } catch (error) {
    error.response ? consoleError(`Error: ${error.response.status}-${error.response.config.url}`) : consoleError(error);
  }
};

/**
 * 上传至oss
 */
async function uploadOSS(command) {
  const info = getExtensionInfo(command.id);
  const dir = getDistPath();
  if (!fs.existsSync(dir)) {
    consoleError('The dist directory does not exist.');
    throw 'not_exist_dist';
  }
  const files = fsExtra.readdirSync(dir).filter((name) => name.includes(info.id));
  try {
    await api.uploadDir(dir, files);
  } catch (error) {
    if (error.response?.data.includes('<Code>FileAlreadyExists</Code>')) {
      consoleWarn('The current file already exists, not need to upload.');
      return;
    } else {
      consoleError('Failed to upload to OSS:', error);
      throw 'upload_failed';
    }
  }
  consoleSuccess('Successfully uploaded to OSS.');
}

/**
 * 发布
 * @returns
 */
async function pushExtension(command) {
  const info = getExtensionInfo(command.id);
  const load = loading(`start push the extension ${info.id}.`).start();
  try {
    const config = getExtensionConfig(command.id);
    const data = {
      resource_url: `https://cn.static.shoplazza.com/chick-extension/${info.distName}`,
      version: config.version,
      scope: '',
      template_name: config.templateName,
      theme_name: config.themeName,
      name: config.extensionName,
      description: config.extensionDescription
    };
    const isFirstPush = !config.extensionId; // 非首次推送
    if (!isFirstPush) {
      data.extension_id = config.extensionId;
    }
    const res = await api.pushExtension(data, isFirstPush);
    const extensionInfo = res.data?.data?.extension || {};

    // 填充本地extensionId
    if (isFirstPush) {
      setExtensionConfig(command.id, {
        ...config,
        extensionId: extensionInfo.extension_id
      });
    }

    // 预览
    const resp = await api.previewExtension({
      extension_id: extensionInfo.extension_id,
      id: extensionInfo.id
    });
    const checkoutUrl = resp.data?.data?.checkout_url;
    const { store: baseUrl } = getProjectConfig();
    const url = new URL(checkoutUrl, baseUrl);
    url.searchParams.append('step', 'contact_information');

    consoleSuccess('\nSuccessfully pushed the extension.');
    consoleBlue(`Your extension's preview URL: ${url.toString()}`);
  } catch (err) {
    consoleError('\n Failed to push the extension: ', err);
    throw 'push_failed';
  } finally {
    load.stop();
  }
}

/**
 * 初始化需要push的extension信息
 */
async function initSelectedExtensionInfo() {
  const PUSH_NEW_EXTENSION = 'Push new extension';
  const res = await api.getExtensionList();
  const extensionList = res.data?.data.extensions || [];
  extensionList.unshift({ extension_id: PUSH_NEW_EXTENSION, name: 'Push new extension' });
  let extensionInfo = await useSelectExtensionMode(extensionList);
  if (extensionInfo.extension_id === PUSH_NEW_EXTENSION) {
    const { extensionName } = await inquirer.prompt([
      {
        type: 'input',
        name: 'extensionName',
        message: 'Please enter the extension name:',
        prefix: '*'
      }
    ]);
    return {
      name: extensionName
    };
  } else {
    checkLocalExtension(extensionInfo);
    return extensionInfo;
  }
}

==> shoplazza-cli-1.0.2.tgz: package/lib/checkout/push.js <==
const fs = require('fs');
const inquirer = require('inquirer');
const api = require('./api');
const loading = require('loading-cli');
const {
  getExtensionInfo,
  getExtensionConfig,
  getDistPath,
  useSelectExtensionMode,
  setExtensionConfig,
  checkLocalExtension,
  getProjectConfig
} = require('./util');
const fsExtra = require('fs-extra');
const { consoleBlue, consoleSuccess, consoleError, consoleWarn } = require('./console');
const { viteBuild } = require('./build');
const { verifyConfig } = require('./verify');

module.exports = async () => {
  try {
    await verifyConfig();
    const extensionInfo = await initSelectedExtensionInfo();
    consoleBlue('Starting to build:');
    const composeCommands = {
      id: extensionInfo.name || extensionInfo.extension_id
    }; // 兼容旧代码处理
    await viteBuild(composeCommands);
    consoleBlue('Starting to upload:');
    await uploadOSS(composeCommands);
    consoleBlue('Starting to push:');
    await pushExtension(composeCommands, extensionInfo);
  } catch (error) {
    error.response ? consoleError(`Error: ${error.response.status}-${error.response.config.url}`) : consoleError(error);
  }
};

/**
 * 上传至oss
 */
async function uploadOSS(command) {
  const info = getExtensionInfo(command.id);
  const dir = getDistPath();
  if (!fs.existsSync(dir)) {
    consoleError('The dist directory does not exist.');
    throw 'not_exist_dist';
  }
  const files = fsExtra.readdirSync(dir).filter((name) => name.includes(info.id));
  try {
    await api.uploadDir(dir, files);
  } catch (error) {
    if (error.response?.data.includes('<Code>FileAlreadyExists</Code>')) {
      consoleWarn('The current file already exists, not need to upload.');
      return;
    } else {
      consoleError('Failed to upload to OSS:', error);
      throw 'upload_failed';
    }
  }
  consoleSuccess('Successfully uploaded to OSS.');
}

/**
 * 发布
 * @returns
 */
async function pushExtension(command, extraInfo) {
  const info = getExtensionInfo(command.id);
  const load = loading(`start push the extension ${info.id}.`).start();
  try {
    const config = getExtensionConfig(command.id);
    // 兼容低版本extension配置文件
    const data = {
      resource_url: `https://cn.static.shoplazza.com/chick-extension/${info.distName}`,
      version: config.version,
      scope: '',
      template_name: config.templateName || config.template_name,
      theme_name: config.themeName || config.theme_name,
      name: config.extensionName || config.extensionId,
      description: config.extensionDescription || '',
      extends_fields: JSON.stringify(config)
    };
    const isFirstPush = !extraInfo.extension_id; // 非首次推送
    if (!isFirstPush) {
      data.extension_id = config.extensionId;
    }
    const res = await api.pushExtension(data, isFirstPush);
    const extensionInfo = res.data?.data?.extension || {};

    // 填充本地extensionId
    if (isFirstPush) {
      setExtensionConfig(command.id, {
        ...config,
        extensionId: extensionInfo.extension_id,
        extensionName: extensionInfo.name,
      });
    }

    load.stop();
    consoleSuccess('Successfully pushed the extension.');
    // 预览
    try {
      const resp = await api.previewExtension({
        extension_id: extensionInfo.extension_id,
        id: extensionInfo.id
      });
      const checkoutUrl = resp.data?.data?.checkout_url;
      const { store: baseUrl } = getProjectConfig();
      const url = new URL(checkoutUrl, baseUrl);
      url.searchParams.append('step', 'contact_information');
      consoleBlue(`Your extension's preview URL: ${url.toString()}`);
    } catch (error) {
      consoleError(error);
    }

  } catch (err) {
    load.stop();
    throw '\nFailed to push the extension: ' + err;
  }
}

/**
 * 初始化需要push的extension信息
 */
async function initSelectedExtensionInfo() {
  const PUSH_NEW_EXTENSION = 'Push new extension';
  const res = await api.getExtensionList();
  const extensionList = res.data?.data.extensions || [];
  extensionList.unshift({ extension_id: PUSH_NEW_EXTENSION, name: 'Push new extension' });
  let extensionInfo = await useSelectExtensionMode(extensionList);
  if (extensionInfo.extension_id === PUSH_NEW_EXTENSION) {
    const { extensionName } = await inquirer.prompt([
      {
        type: 'input',
        name: 'extensionName',
        message: 'Please enter the extension name:',
        prefix: '*'
      }
    ]);
    return {
      name: extensionName
    };
  } else {
    checkLocalExtension(extensionInfo);
    return extensionInfo;
  }
}
